@@ -4,7 +4,7 @@ import torch.nn.functional as F
 import torch.optim as optim
 import math
 from aiopslibs.utils import FeaturesHandler, PlotUtilities
-
+import  json
 class SimpleTextClassifier(nn.Module):  # inherit pytorch's nn.Module
     """Text Classifier with 1 hidden layer 
     """
@@ -54,7 +54,6 @@ class ModelsEvaluator:
         with torch.no_grad():
             print("torch.no_grad() go:")
             for feature_vector, label, _id in zip(X_eval, y_eval, ids):
-                print("type(_id) :", type(_id))
                 log_probs = model(feature_vector)
                 # get confidence that item is disaster-related
                 prob_related = math.exp(log_probs.data.tolist()[0][1])
@@ -170,6 +169,18 @@ class EvalModelPloter:
         self.run = run
         self.modelsEvaluator = ModelsEvaluator()
 
+    def _log_confusion_matrix_artefact(self, true_pos_text, false_neg_text,false_pos_text,true_neg_text):
+        data = {}
+        data["true_pos_text"] = true_pos_text
+        data["false_neg_text"] = false_neg_text
+        data["false_pos_text"] = false_pos_text
+        data["true_neg_text"] = true_neg_text
+        confusion_matrix_log = "confusion_matrix_log.json"
+        with open("confusion_matrix_log.json", 'w') as outfile:
+                json.dump(data, outfile)
+        
+        self.run.upload_file(name="confusion_matrix_log", path_or_stream=confusion_matrix_log)
+
     def evaluate(self, model, eval_data, text_data):
         """retrieve model metrics and log them in the Workspace
 
